/*
DAC Out 5V

Platform: Arduino Mini
*/

#include "EPT_SineTool.h"
#include <SPI.h>

//DAC Configuration Register Bits 
#define DAC_WRITE        0x00 //Bit 15: 0 to Write to DAC register
#define DAC_BUFFER       0x40 //Bit 14: 1 to Buffer VREF
#define DAC_GAIN_SELECT  0x20 //Bit 13: 1 to set Gain to 1x
#define DAC_SHDN         0x10 //Bit 12: 1 to set Active Mode operation 

const int DACSelectPin = 10;

unsigned char DACConfigAndCountValue;
unsigned char DACCountHighValue;
unsigned char DACCountLowValue;
unsigned char byteToSendToDAC;
unsigned char sineWaveIndex;
unsigned char upperByteForDAC;
unsigned char lowerByteForDAC;

void setup() {
  pinMode (DACSelectPin, OUTPUT);

  DACConfigAndCountValue = DAC_WRITE | DAC_BUFFER | DAC_GAIN_SELECT | DAC_SHDN;
  DACCountHighValue = 0;
  DACCountLowValue = 0;
  byteToSendToDAC = 0;
  sineWaveIndex = 0;
  upperByteForDAC = 0;
  lowerByteForDAC = 0;
  
  //Initialize SPI
  SPI.begin();

  //Initialize the Sine Wave Tool
  EPT_SineToolInit();

  //Initialize the Debug Port
  //Serial.begin(115200);

}

void loop()
{
   //Select Sine Wave data value
   byteToSendToDAC = EPT_SineToolData(sineWaveIndex);
   //delay(1);

   //Set the upper byte to send to the DAC
   DACCountHighValue = byteToSendToDAC>>4;
   upperByteForDAC = DACConfigAndCountValue | DACCountHighValue;

   //Set the lower byte to send to the DAC
   lowerByteForDAC = byteToSendToDAC<<4;
   //Select the DAC chip;
   digitalWrite(DACSelectPin, LOW);
   
   //Send in the address and value via SPI:
   SPI.transfer(upperByteForDAC);
   //Send Header Byte 1
   SPI.transfer(lowerByteForDAC);

   
   //Take the SS pin high to de-select the DAC chip;
   digitalWrite(DACSelectPin, HIGH);
   
   //delay the sine wave;
   EPT_SineToolDelay(0);
   
   //Update the sine wave index
   sineWaveIndex += 1;

}
